import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface TeamAccessConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tfe/r/team_access#access TeamAccess#access}
    */
    readonly access?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tfe/r/team_access#id TeamAccess#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tfe/r/team_access#team_id TeamAccess#team_id}
    */
    readonly teamId: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tfe/r/team_access#workspace_id TeamAccess#workspace_id}
    */
    readonly workspaceId: string;
    /**
    * permissions block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tfe/r/team_access#permissions TeamAccess#permissions}
    */
    readonly permissions?: TeamAccessPermissions[] | cdktf.IResolvable;
}
export interface TeamAccessPermissions {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tfe/r/team_access#run_tasks TeamAccess#run_tasks}
    */
    readonly runTasks: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tfe/r/team_access#runs TeamAccess#runs}
    */
    readonly runs: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tfe/r/team_access#sentinel_mocks TeamAccess#sentinel_mocks}
    */
    readonly sentinelMocks: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tfe/r/team_access#state_versions TeamAccess#state_versions}
    */
    readonly stateVersions: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tfe/r/team_access#variables TeamAccess#variables}
    */
    readonly variables: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tfe/r/team_access#workspace_locking TeamAccess#workspace_locking}
    */
    readonly workspaceLocking: boolean | cdktf.IResolvable;
}
export declare function teamAccessPermissionsToTerraform(struct?: TeamAccessPermissions | cdktf.IResolvable): any;
export declare class TeamAccessPermissionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): TeamAccessPermissions | cdktf.IResolvable | undefined;
    set internalValue(value: TeamAccessPermissions | cdktf.IResolvable | undefined);
    private _runTasks?;
    get runTasks(): boolean | cdktf.IResolvable;
    set runTasks(value: boolean | cdktf.IResolvable);
    get runTasksInput(): boolean | cdktf.IResolvable | undefined;
    private _runs?;
    get runs(): string;
    set runs(value: string);
    get runsInput(): string | undefined;
    private _sentinelMocks?;
    get sentinelMocks(): string;
    set sentinelMocks(value: string);
    get sentinelMocksInput(): string | undefined;
    private _stateVersions?;
    get stateVersions(): string;
    set stateVersions(value: string);
    get stateVersionsInput(): string | undefined;
    private _variables?;
    get variables(): string;
    set variables(value: string);
    get variablesInput(): string | undefined;
    private _workspaceLocking?;
    get workspaceLocking(): boolean | cdktf.IResolvable;
    set workspaceLocking(value: boolean | cdktf.IResolvable);
    get workspaceLockingInput(): boolean | cdktf.IResolvable | undefined;
}
export declare class TeamAccessPermissionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: TeamAccessPermissions[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): TeamAccessPermissionsOutputReference;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/tfe/r/team_access tfe_team_access}
*/
export declare class TeamAccess extends cdktf.TerraformResource {
    static readonly tfResourceType = "tfe_team_access";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/tfe/r/team_access tfe_team_access} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options TeamAccessConfig
    */
    constructor(scope: Construct, id: string, config: TeamAccessConfig);
    private _access?;
    get access(): string;
    set access(value: string);
    resetAccess(): void;
    get accessInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _teamId?;
    get teamId(): string;
    set teamId(value: string);
    get teamIdInput(): string | undefined;
    private _workspaceId?;
    get workspaceId(): string;
    set workspaceId(value: string);
    get workspaceIdInput(): string | undefined;
    private _permissions;
    get permissions(): TeamAccessPermissionsList;
    putPermissions(value: TeamAccessPermissions[] | cdktf.IResolvable): void;
    resetPermissions(): void;
    get permissionsInput(): cdktf.IResolvable | TeamAccessPermissions[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
